function run_exp_KL

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function reproduces the results of the KL-Divergence for Example 1,
% reported in Supplemental Material (Figs. 2-4).
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all

%Initialization
vec_N = [600:100:900 1000 3000 9000];     %sample sizes
Nmax = vec_N(end);                        %max. sample size                     
vec_p = 10;                         %true order
pmin = 1;                           %min. AR order in estimation
pmax = 20;                          %max. AR order in estimation                            
n = 5;                              %no. of variables
k = 8;                              %max. no. of 0's in the upper triangular part
% Ntr = 100;                          %no. of realizations for each model
Ntr = 3;
Ngrid = 1024;                       %no. of grid points for KL divergence
NoCrit = 7;                         %number of criteria
% Crit1 = SBC
% Crit2 = FPE
% Crit3 = RNML
% Crit4 = AIC
% Crit5 = AICc
% Crit6 = KIC
% Crit7 = KICc
% 
ze = zeros(1,Ntr*k);
ord = cell(NoCrit,length(vec_N));
for crit=1:NoCrit,
    for ind_N=1:length(vec_N),
        ord{crit,ind_N}=ze;
    end
end
%
on = Inf*ones(1,Ntr*k);
J = cell(NoCrit,length(vec_N));
for crit=1:NoCrit,
    for ind_N=1:length(vec_N),
        J{crit,ind_N}=on;
    end
end
Imax = J;
J2 = J;
Imax2 = J;
%
count = zeros(NoCrit,length(vec_N));

%Mask_set contains all the masks we use
[mask_set, flag_err] = generate_mask_set(n,k);
if flag_err,
    return;
end

fprintf('\n');

for ind_p=1:length(vec_p),
    %True order
    p = vec_p(ind_p);
    for ind_mask=2:k+1, %Do not consider the mask full of ones
        %True mask
        no_true = ind_mask;
        mask = mask_set(:,(no_true-1)*n+1:no_true*n);
        mask_estim = xor(mask,ones(n,n)); %used in the estimation part
        %Generate model
        [Ytrue, A, Sigma] = gen_IS_model(n, p, mask);
%         [Ytrue2,~] = comp_IShat(n,p,Sigma,A);
%         J=comp_intKL(Ytrue, Ytrue2)
%         pause
        for ind_tr=1:Ntr,
            %Generate data
            all_data = arsim(zeros(n,1),A,Sigma,Nmax);
            for ind_N = 1:length(vec_N),
                %Sample size
                N = vec_N(ind_N);
                data = all_data(1:N,:);
                %Estimate order
                [vec_phat, vec_phat_short, Atot1, Sigmatot1]=arfit_mod(data, pmin, pmax);
                Rest_max = comp_R(data,max(vec_phat_short));
                %Results for order estimation
                for crit=1:NoCrit,
                    ord{crit,ind_N}((ind_mask-2)*Ntr+ind_tr) = vec_phat(crit);
                end %for crit
                %Compute KL
                lvps = length(vec_phat_short);
                for ind_phs = 1:lvps,
                    [Yestim,flag] = comp_IShat(n,vec_phat_short(ind_phs),Sigmatot1{ind_phs},Atot1{ind_phs});
                    if flag,
                        phat = vec_phat_short(ind_phs);
                        ff = find(vec_phat==phat);
                        for ind_ff = 1:length(ff),
                            crit = ff(ind_ff);
                            count(crit,ind_N) = count(crit,ind_N)+1;
                            [Jtemp,Imaxtemp] = comp_intKL(Ytrue, Yestim, Ngrid);
                            J{crit,ind_N}((ind_mask-2)*Ntr+ind_tr) = Jtemp;
                            Imax{crit,ind_N}((ind_mask-2)*Ntr+ind_tr) = Imaxtemp;
                            Yout = max_entropy(n, phat, mask_estim, Rest_max); %max_entropy takes what it needs from Rest_max
                            [Jtemp,Imaxtemp] = comp_intKL(Ytrue, Yout, Ngrid);
                            J2{crit,ind_N}((ind_mask-2)*Ntr+ind_tr) = Jtemp;
                            Imax2{crit,ind_N}((ind_mask-2)*Ntr+ind_tr) = Imaxtemp;
                        end %crit
                    end %flag
                end %ind_phs
            end %sample size
        end %trial
    end % mask
save('Result_KL.mat','ord','J','Imax','J2','Imax2','count','vec_N','NoCrit');
fprintf('*');
end %order

fprintf('\n');
end %function



