function [B, Sigma] = gen_BD_model(n, p)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Generates AR models according to
%C.-M. Ting et al., "Is First-Order Vector Autoregressive Model Optimal 
% for fMRI Data?", Neural Computation 27, 18571871 (2015),
%Section 3.1, Table 2.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%input:
% n           = no. of variables (time series)
% p           = order of the true AR model
%output
% B           = coefficients of AR model
% Sigma       = cov. matrix driven noise
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

lambda = 1.35;

flag_stab_check=0;
while flag_stab_check==0,
        for ind=1:p,
            temp1 = rand(10,10)-ones(10,10)/2;
            temp2 = rand(10,10)-ones(10,10)/2;
            Btemp = [temp1 zeros(10,10); zeros(10,10) temp2];
            dia = diag(Btemp);
            Btemp = Btemp/lambda^p;
             for ii=1:20,
                 Btemp(ii,ii) = dia(ii);
             end
            B(:,(ind-1)*n+1:ind*n) = Btemp;
        end
        
        % Check the stability.
        comp = [B; eye(n*(p-1)) zeros(n*(p-1),n)];
        flag_stab_check = (max(abs(eig(comp)))<1);
end
Sigma = eye(20,20);

% comp_poles(p, B);
% pause
% close all

end% function 

