function run_exp_order_2

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function produces the results for Example 2, reported in 
% Supplemental Material (Fig. 5).
%
% Example from C.-M. Ting et al., "Is First-Order Vector 
% Autoregressive Model Optimal for fMRI Data?", 
% Neural Computation 27, 18571871 (2015), Section 3.1, Table 2.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all

%Initialization
vec_N = 200:25:275;      %sample sizes
Nmax = vec_N(end);       %max. sample size
vec_p = [1 2];           %order AR model
pmin = 1;                %min. AR order in estimation
pmax = 8;                %max. AR order in estimation
n = 20;                  %no. of time series
Ntr = 10000;             %no. of realizations for each model

% Crit1 = SBC
% Crit2 = FPE
% Crit3 = RNML
% Crit4 = AIC
% Crit5 = AICc
% Crit6 = KIC
% Crit7 = KICc
%
ZE = zeros(length(vec_p),1);
%
ord_eq = cell(7,length(vec_N));
for crit=1:7,
    for ind_N=1:length(vec_N),
        ord_eq{crit,ind_N}=ZE;
    end
end
%
ord_under = cell(7,length(vec_N));
for crit=1:7,
    for ind_N=1:length(vec_N),
        ord_under{crit,ind_N}=ZE;
    end
end
clear crit;

fprintf('\n');

for ind_p=1:length(vec_p),
    %True order
    p = vec_p(ind_p);
    ZEc = ZE;
    ZEc(ind_p,1)=1;
        for ind_tr=1:Ntr,
            [A, Sigma] = gen_BD_model(n, p);
            %Generate data
            all_data = arsim(zeros(n,1),A,Sigma,Nmax);
            for ind_N = 1:length(vec_N),
                %Sample size
                N = vec_N(ind_N);
                data = all_data(1:N,:);
                %Estimate order
                vec_phat = arfit_mod(data, pmin, pmax);
                %Results for order estimation
                for crit=1:7,
                    if vec_phat(crit)==p,
                        ord_eq{crit,ind_N} = ord_eq{crit,ind_N} + ZEc;
                    elseif vec_phat(crit)<p,
                        ord_under{crit,ind_N} = ord_under{crit,ind_N} + ZEc;
                    else
                    end
                end %for crit
            end %sample size
        end %trial
  
    
    save('Results_Example_2','ord_eq','ord_under','vec_N','Ntr','vec_p');
    fprintf('*');
end %order

fprintf('\n');
end %function



